@@ -11,14 +11,18 @@ def find_slaveaddress(portname):
     instrument.serial.baudrate = 9600
     instrument.serial.timeout = 0.1
 
+    addresses = []
+
     for address in range(0x01, 0xf8):
         instrument.address = address
         try:
             try:
-                value = instrument.read_string(0x1402, 8)
-                print(address, value)
-            except:
-                value = instrument.read_string(0x000C, 16)
-                print(address, value)
-        except:
+                instrument.read_string(0x1402, 8)
+                addresses.append(address)
+            except minimalmodbus.ModbusException:
+                instrument.read_string(0x000C, 16)
+                addresses.append(address)
+        except minimalmodbus.ModbusException:
             pass
+   
+    return addresses
